@@ -49,6 +49,10 @@ class Encoding():
                 print(decode,end="\n")
             else:
                 print(decode,end="")
+    def findrate(self):
+        print(self.rate)
+        for k,v,i in self.encoding.reverse:
+            print(f'{i}:  {k}:{v},')
 class ListEncoding():
     def __init__(self,mix):
         self.encoding = []
